%%%
%%% Esempio di progetto di schema in
%%% retroazione a tempo continuo e 
%%% tempo discreto: strumenti di
%%% analisi
%%%

% Sistema da controllare:
% G(s) = 1/(s*(s+10)*(s+50))

s=tf('s') % Variabile simbolica di Laplace

Gs= 1/(s*(s+10)*(s+50)) % Sistema da
                        % controllare
                        
[numGs,denGs]=tfdata(Gs,'v') % Esporto i vettori
                             % da usare in Simulink
                             
Gr=Gs/(1+Gs) % Funzione di trasferimento del sistema
             % in retroazione unitaria
             
[numGr,denGr]=tfdata(Gs,'v') % Analizzo i poli della
                             % fdt in retroazione
                             
roots(denGr) % Calcolo i poli di Gr(s)

% Verifico che il sistema in retroazione è stabile
% e presenta un polo dominante

% La dinamica del sistema in retroazione è assimilabile
% alla risposta di un modello del 1o ordine, con
% risposta y(t) = 1 - exp(-t/tau), con tau costante
% di tempo del polo dominante tau = 1/0.0020
% con tempo di assestamento Ta=3/(delta*omega_n)
% Ta=3/0.0020 (tempo di assestamento di un sistema
% del 1o ordine secondo il polo dominante)

lsiminfo(ync,tsim) % verifico i parametri della
                   % risposta in transitorio  
                   
rlocus(Gs) % disegna il luogo delle radici, ovvero
           % le radici del polinomio F(s), con
           % F(s) = 1 + K*G(s)

% Funzione di trasferimento del controllore (dato)

Rs=(1+s/15)/(1+s/100) % forma a costanti di tempo

[numRs,denRs]=tfdata(Rs,'v') % esporto le variabili
                             % per Simulink

% Nota: R(0) = 1

% Guadagno statico della rete correttrice

K = 6050;

lsiminfo(yc,tsim) % noto il miglioramento decisivo
                  % del tempo di assestamento (0.45s) e
                  % una sovraelongazione del 7.55%

% Analisi dei luoghi delle radici dei sistemi
% non compensato e compensato

Ga=K*Rs*Gs % funzione di anello

Grc=Ga/(1+Ga) % fdt del sistema compensato in
              % retroazione
              
[numGrc,denGrc]=tfdata(Grc,'v') % analisi stabilità
                                % eventuale
roots(denGrc) % per lo studio della stabilità  
              % sistema stabile
              
Ga = Rs*Gs    % funzione d'anello per luogo delle 
              % radici
              
rlocus(Ga)    % Luogo delle radici per K variabile              

rlocus(Gs,'-r',Ga,'--g') % confronto luoghi radici

T=0.0040 % tempo di campionamento

z=tf('z',T) % Definisco la variabile z

Rz=(5.722*z-5.389)/(z-0.6667) % Regolatore a tempo discreto
                              %
                              
[numRz,denRz]=tfdata(Rz,'v')                              
                              
lsiminfo(yd,tsim) % verifico le prestazioni del
                  % sistema in digitale